==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/extmenulist_001/ExtMenu.java <==

package net.datastream.schemas.mp_entities.extmenulist_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMENUID_Type;
import net.datastream.schemas.mp_fields.FUNCTIONID_Type;
import net.datastream.schemas.mp_fields.PERMISSIONS_Type;
import net.datastream.schemas.mp_fields.TABID_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARENTSCREEN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TABID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU"/>
 *         &lt;element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extmenuid",
    "usergroupid",
    "functionid",
    "extmenuparent",
    "parentscreen",
    "extmenutype",
    "sequencenumber",
    "systempermissions",
    "usergrouppermissions",
    "tabid",
    "hidemenu",
    "updatecount"
})
@XmlRootElement(name = "ExtMenu")
public class ExtMenu {

    @XmlElement(name = "EXTMENUID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EXTMENUID_Type extmenuid;
    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "FUNCTIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "EXTMENUPARENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String extmenuparent;
    @XmlElement(name = "PARENTSCREEN", namespace = "http://schemas.datastream.net/MP_fields")
    protected FUNCTIONID_Type parentscreen;
    @XmlElement(name = "EXTMENUTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long sequencenumber;
    @XmlElement(name = "SYSTEMPERMISSIONS", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERMISSIONS_Type systempermissions;
    @XmlElement(name = "USERGROUPPERMISSIONS", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERMISSIONS_Type usergrouppermissions;
    @XmlElement(name = "TABID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TABID_Type tabid;
    @XmlElement(name = "HIDEMENU", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String hidemenu;
    @XmlElement(name = "UPDATECOUNT")
    protected Long updatecount;

    /**
     * Obtient la valeur de la propriété extmenuid.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public EXTMENUID_Type getEXTMENUID() {
        return extmenuid;
    }

    /**
     * Définit la valeur de la propriété extmenuid.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public void setEXTMENUID(EXTMENUID_Type value) {
        this.extmenuid = value;
    }

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Obtient la valeur de la propriété functionid.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Définit la valeur de la propriété functionid.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Obtient la valeur de la propriété extmenuparent.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Définit la valeur de la propriété extmenuparent.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Obtient la valeur de la propriété parentscreen.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getPARENTSCREEN() {
        return parentscreen;
    }

    /**
     * Définit la valeur de la propriété parentscreen.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setPARENTSCREEN(FUNCTIONID_Type value) {
        this.parentscreen = value;
    }

    /**
     * Obtient la valeur de la propriété extmenutype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Définit la valeur de la propriété extmenutype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Obtient la valeur de la propriété sequencenumber.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Définit la valeur de la propriété sequencenumber.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSEQUENCENUMBER(Long value) {
        this.sequencenumber = value;
    }

    /**
     * Obtient la valeur de la propriété systempermissions.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getSYSTEMPERMISSIONS() {
        return systempermissions;
    }

    /**
     * Définit la valeur de la propriété systempermissions.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setSYSTEMPERMISSIONS(PERMISSIONS_Type value) {
        this.systempermissions = value;
    }

    /**
     * Obtient la valeur de la propriété usergrouppermissions.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getUSERGROUPPERMISSIONS() {
        return usergrouppermissions;
    }

    /**
     * Définit la valeur de la propriété usergrouppermissions.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setUSERGROUPPERMISSIONS(PERMISSIONS_Type value) {
        this.usergrouppermissions = value;
    }

    /**
     * Obtient la valeur de la propriété tabid.
     * 
     * @return
     *     possible object is
     *     {@link TABID_Type }
     *     
     */
    public TABID_Type getTABID() {
        return tabid;
    }

    /**
     * Définit la valeur de la propriété tabid.
     * 
     * @param value
     *     allowed object is
     *     {@link TABID_Type }
     *     
     */
    public void setTABID(TABID_Type value) {
        this.tabid = value;
    }

    /**
     * Obtient la valeur de la propriété hidemenu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Définit la valeur de la propriété hidemenu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Obtient la valeur de la propriété updatecount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Définit la valeur de la propriété updatecount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUPDATECOUNT(Long value) {
        this.updatecount = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/extmenulist_001/ExtMenu.java <==

package net.datastream.schemas.mp_entities.extmenulist_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMENUID_Type;
import net.datastream.schemas.mp_fields.FUNCTIONID_Type;
import net.datastream.schemas.mp_fields.PERMISSIONS_Type;
import net.datastream.schemas.mp_fields.TABID_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMENUID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PARENTSCREEN" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SYSTEMPERMISSIONS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERGROUPPERMISSIONS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TABID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU"/>
 *         <element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extmenuid",
    "usergroupid",
    "functionid",
    "extmenuparent",
    "parentscreen",
    "extmenutype",
    "sequencenumber",
    "systempermissions",
    "usergrouppermissions",
    "tabid",
    "hidemenu",
    "updatecount"
})
@XmlRootElement(name = "ExtMenu")
public class ExtMenu {

    @XmlElement(name = "EXTMENUID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EXTMENUID_Type extmenuid;
    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "FUNCTIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "EXTMENUPARENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String extmenuparent;
    @XmlElement(name = "PARENTSCREEN", namespace = "http://schemas.datastream.net/MP_fields")
    protected FUNCTIONID_Type parentscreen;
    @XmlElement(name = "EXTMENUTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long sequencenumber;
    @XmlElement(name = "SYSTEMPERMISSIONS", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERMISSIONS_Type systempermissions;
    @XmlElement(name = "USERGROUPPERMISSIONS", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERMISSIONS_Type usergrouppermissions;
    @XmlElement(name = "TABID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TABID_Type tabid;
    @XmlElement(name = "HIDEMENU", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String hidemenu;
    @XmlElement(name = "UPDATECOUNT")
    protected Long updatecount;

    /**
     * Gets the value of the extmenuid property.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public EXTMENUID_Type getEXTMENUID() {
        return extmenuid;
    }

    /**
     * Sets the value of the extmenuid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public void setEXTMENUID(EXTMENUID_Type value) {
        this.extmenuid = value;
    }

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Gets the value of the functionid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Sets the value of the functionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Gets the value of the extmenuparent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Sets the value of the extmenuparent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Gets the value of the parentscreen property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getPARENTSCREEN() {
        return parentscreen;
    }

    /**
     * Sets the value of the parentscreen property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setPARENTSCREEN(FUNCTIONID_Type value) {
        this.parentscreen = value;
    }

    /**
     * Gets the value of the extmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Sets the value of the extmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSEQUENCENUMBER(Long value) {
        this.sequencenumber = value;
    }

    /**
     * Gets the value of the systempermissions property.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getSYSTEMPERMISSIONS() {
        return systempermissions;
    }

    /**
     * Sets the value of the systempermissions property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setSYSTEMPERMISSIONS(PERMISSIONS_Type value) {
        this.systempermissions = value;
    }

    /**
     * Gets the value of the usergrouppermissions property.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getUSERGROUPPERMISSIONS() {
        return usergrouppermissions;
    }

    /**
     * Sets the value of the usergrouppermissions property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setUSERGROUPPERMISSIONS(PERMISSIONS_Type value) {
        this.usergrouppermissions = value;
    }

    /**
     * Gets the value of the tabid property.
     * 
     * @return
     *     possible object is
     *     {@link TABID_Type }
     *     
     */
    public TABID_Type getTABID() {
        return tabid;
    }

    /**
     * Sets the value of the tabid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TABID_Type }
     *     
     */
    public void setTABID(TABID_Type value) {
        this.tabid = value;
    }

    /**
     * Gets the value of the hidemenu property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Sets the value of the hidemenu property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Gets the value of the updatecount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Sets the value of the updatecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUPDATECOUNT(Long value) {
        this.updatecount = value;
    }

}
